[English](./README.md)

ابزار خط فرمان makenote
---

یک ابزار خط فرمان برای نوشتن یادداشت‌ها، نوشته‌های روزمره، گزارش‌کار و غیره.

# نصب

چند روش برای نصب این ابزار وجود دارد. روش اول توصیه می‌شود.

## نصب با مدیربستهٔ پایتون
1. با استفاده از مدیربستهٔ پایتون این ابزار را نصب کنید:  
```bash
pip install makenote
```

2. ر صورتی که پیش از این انجام نداده‌اید، مسیر `~/.local/bin` را به مسیر فایل‌های اجرایی اضافه کنید. ([راهنما](https://linuxize.com/post/how-to-add-directory-to-path-in-linux/))

## نصب محلی

1. این مخزن را بارگیری کنید و وارد آن شوید.
2. اسکریپت مقابل را اجرا کنید تا برنامه نصب شود: `install_local.sh`
3. در صورتی که پیش از این انجام نداده‌اید، مسیر `~/.local/bin` را به مسیر فایل‌های اجرایی اضافه کنید. ([راهنما](https://linuxize.com/post/how-to-add-directory-to-path-in-linux/))

## بیلد کردن مخزن برای مدیربستهٔ پایتون

مشابه بسیاری از مخزن‌های پایتونی دیگر عمل کنید.
1. بیلد کردن
```bash
pip install setuptools wheel
git clone 'https://github.com/ekm507/makenote'
cd makenote
python3 setup.py bdist_wheel
```

2. نصب
```bash
pip install dist/*.whl
```



<!-- 
### پیش از نصب

پیش از نصب مطمئن باشید نیازمندی‌های برنامه نصب شده‌است.  
این برنامه از sqlite3 استقاده می‌کند. برای نصب آن در سیستم‌های دبیانی از این دستور استفاده کنید:



```bash
apt install sqlite3
```

### نصب

ابتدا این مخزن را کلون کنید:


```bash
git clone 'https://github.com/ekm507/makenote.git'
```

سپس فایل `install.sh` را با دسترسی روت اجرا کنید:

```bash
./install.sh
``` -->

# استفاده

## ایجاد جدول

این ابزار نوشته‌ها را در جدول‌های مختلف نگه‌داری می‌کند. شما می‌توانید نوشته‌های خود را در دسته‌بندی‌هایی مثل journals, tasks, work و غیره نگه‌داری کنید..

برای ایجاد یک جدول دستور خط فرمان زیر را اجرا کنید:



```bash
makenote --create <table_name>
```

## افزودن یک یادداشت

برای اضافه کردن یک یادداشت به یکی از جدول‌ها، دستور زیر را اجرا کنید:

اگر اسم جدول مشخص نشود، جدول پیشفرض با اسم journals استفاده خواهدشد.


```bash
makenote [-t <table_name>] <note_text>
```

مثال:
```bash
makenote این یادداشت را ذخیره کن
```

هم‌چنین این ابزار می‌تواند ورودی را به جای خط فرمان، از ورودی stdin دریافت کند. برای مثال می‌توانید از این ابزار به این شکل استفاده کنید:


```bash
echo "من این ابزار را نصب کردم" | makenote --table journals
```


## دیدن لیست جدول‌ها

برای دیدن یک لیست از اسم جدول‌های ایجادشده، از این دستور استفاده کنید:


```bash
makenote --list
```

## مشاهده یک جدول

برای دیدن یادداشت‌های داخل یکی از جدول‌ها، از این دستور استفاده کنید:


```bash
makenote --show <table_name>
```


# استخراج همهٔ نوشته‌ها
پایگاه دادهٔ برنامه در مسیر زیر ذخیره می‌شود.

`~/.local/share/makenote/databases/diaryFile.db`

برای پشتیبان‌گیری کافیست این مخزن را بردارید.

به‌منظور بازآوری یادداشت‌ها (مثلاً هنگام جابجایی بین دو سیستم)، سند `diaryFile.db` را در همان مسیر قبلی جایگذاری کنید.

